Task: WikiSQL semantic parsing task
====================================
Description: Dataset for parsing sentences to SQL code, given a table. Implemented as part of the DecaNLP task. More info can be found here:https://github.com/salesforce/WikiSQL

Tags: #wikisql, #All, #decanlp

